'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/**
 * 重构url
 * @param  {Object}
 * @return {String}
 */
var getConstructUrl = exports.getConstructUrl = function getConstructUrl(route) {
	var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	// 创建新的url
	var path = route.path,
	    query = route.query;

	var result = path.join('/');
	var queryArr = [];
	if (query && (typeof query === 'undefined' ? 'undefined' : _typeof(query)) === 'object') {
		queryArr = Object.keys(query).sort().filter(function (key) {
			return query[key] !== null;
		}).map(function (key) {
			return key + '=' + query[key];
		});
	}

	if (queryArr.length > 0) {
		result += '?' + queryArr.join('&');
	}

	return result;
};
/**
 * 解析url
 * @param  {String} url
 * @return {Object}
 */
var getParseUrl = exports.getParseUrl = function getParseUrl() {
	var url = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '' + location.pathname + decodeURIComponent(location.search);
	var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	// 解析url
	var path = [];
	var query = {};
	// const urlArr = url.replace('/', '').split('?');
	var urlArr = url.split('?');
	path = urlArr[0].split('/');

	if (urlArr.length > 1) {
		urlArr[1].split('&').forEach(function (str) {
			var arr = str.split('=');
			var key = arr[0];
			var value = arr[1];
			// 009, ''
			if (isNaN(value) || value[0] === '0' || value === '' || value > Number.MAX_SAFE_INTEGER) {
				query[key] = value;
			} else {
				query[key] = Number(value);
			}
		});
	}

	return {
		path: path,
		query: query
	};
};
/**
 * 重构Url
 * @param  {[type]} paramObj url的参数对象
 * @param  {[type]} url      url
 * @return {[type]}          新的url
 */
var getHashUrl = exports.getHashUrl = function getHashUrl() {
	var url = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
	var paramObj = arguments[1];
	var opts = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

	var paramArray = [];
	for (var key in paramObj) {
		if (paramObj[key] || paramObj[key] === false || paramObj[key] === 0) {
			// 过滤掉值为null,undefined,''情况
			paramArray = [].concat(_toConsumableArray(paramArray), [key + '=' + encodeURIComponent(paramObj[key])]);
		}
	}
	return url + '?' + paramArray.join('&');
};
/**
 * 查找url中key的值
 * @param  {String} key
 * @param  {String} urlInfo
 * @return {String}
 */
var getUrlParam = exports.getUrlParam = function getUrlParam(key, urlInfo) {
	var opts = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

	var regExp = new RegExp("(^|&)" + key + "=([^&]*)(&|$)");
	var url = urlInfo ? urlInfo.substring(urlInfo.indexOf('?')) : window.location.search;
	var value = decodeURI(url).substr(1).match(regExp);

	return value != null ? unescape(value[2]) : null;
};